@@ -10,6 +10,7 @@
 #' @param y numeric vector with outputs / scores. If provided then it shall have the same size as \code{data}.
 #' @param weights numeric vector with sampling weights. By default it's \code{NULL}. If provided then it shall have the same length as \code{data}
 #' @param predict_function function that takes two arguments: model and new data and returns numeric vector with predictions
+#' @param predict_function_target_column Character or numeric containing either column name or column number in the model prediction object of the class that should be considered as positive (ie. the class that is associated with probability 1). If NULL, the second column of the output will be taken for binary classification. For a multiclass classification setting that parameter cause switch to binary classification mode with 1 vs others probabilities.
 #' @param residual_function function that takes three arguments: model, data and response vector y. It should return a numeric vector with model residuals for given data. If not provided, response residuals (\eqn{y-\hat{y}}) are calculated.
 #' @param ... other parameters
 #' @param label character - the name of the model. By default it's extracted from the 'class' attribute of the model
@@ -61,6 +62,7 @@ explain_mlr <-
            y = NULL,
            weights = NULL,
            predict_function = NULL,
+           predict_function_target_column = NULL,
            residual_function = NULL,
            ...,
            label = NULL,
@@ -75,6 +77,7 @@ explain_mlr <-
       y = y,
       weights = weights,
       predict_function = predict_function,
+      predict_function_target_column = predict_function_target_column,
       residual_function = residual_function,
       ...,
       label = label,
